<?php
namespace HCM\FPA\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\Repositories;

class ResumoContabilRepository {

    public function __construct(Connection $connection, EntityManager $entityManager) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;

        $this->fpaResumoctbl = Repositories::FPA_RESUMOCTBL;
    }

    /**
     * Retorna as estruturas superiores do resumo contábil.
     *
     * @param string $dtocorrencia
     * @param int $nrorg
     * @param int $nrtipomoviment
     * @return int[]
     */
    public function getEstruturasSupResumo($dtocorrencia, $nrorg, $nrtipomoviment)
    {
        $sql = <<<SQL
SELECT r
  FROM $this->fpaResumoctbl r
 WHERE r.nrorg = :P_NRORG
   AND r.dtocorrencia = '$dtocorrencia'
   AND (r.nrtipomoviment = :P_NRTIPOMOVIMENT OR :P_NRTIPOMOVIMENT IS NULL)
SQL;
        $params = array(
            'P_NRORG' => $nrorg,
            'P_NRTIPOMOVIMENT' => $nrtipomoviment
        );

        $resultado = $this->entityManager->createQuery($sql)->execute($params);

        return $resultado;
    }
    
    
    public function getEstruturasSupResCont($dtocorrencia, $nrorg, $nrtipomoviment, $listaestrutsup = null) {
        $where = '';
        
        if($listaestrutsup)
            $where = " AND NRESTRUTURAMSUP IN ($listaestrutsup)";
        
        $query = $this->connection->prepare(
            "SELECT DISTINCT NRESTRUTURAMSUP
                    FROM FPA_RESUMOCTBL
                WHERE NRORG = :P_NRORG
                    AND DTOCORRENCIA = '$dtocorrencia'
                    AND (NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT OR :P_NRTIPOMOVIMENT IS NULL)
                    $where
            "
        );

      $query->execute(
        array(
            'P_NRORG' => $nrorg,
            'P_NRTIPOMOVIMENT' => $nrtipomoviment
        )
      );
      

      return $query->fetchAll();
    }

} 
