<?php
namespace HCM\Geral\Controllers;

use HCM\Geral\Services\PreFechamentoDctfWebService;
use HCM\Util\HCMParameters;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class PreFechamentoDctfWebController {
    
    public function __construct (HCMParameters $hcmParameters, PreFechamentoDctfWebService $preFechamentoDctfWebService) {
        $this->hcmParameters = $hcmParameters;
        $this->preFechamentoDctfWebService = $preFechamentoDctfWebService;
        $this->contribuicaoPrevidenciariaSegurado = new ContribuicaoPrevidenciariaSegurado($hcmParameters, $preFechamentoDctfWebService);
        $this->informacoesSinteticas = new InformacoesSinteticas($hcmParameters, $preFechamentoDctfWebService);
        $this->informacoesSobreBasesCalculo = new InformacoesSobreBasesCalculo($hcmParameters, $preFechamentoDctfWebService);
    }
    
    public function getContribuicaoPrevidenciariaSegurado(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->contribuicaoPrevidenciariaSegurado->getContribuicaoPrevidenciariaSegurado($request->getDataSet()->getRows()[0], $response);
    }
    
    public function getEventosApuradosContribuicao(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->contribuicaoPrevidenciariaSegurado->getEventosApurados($request->getDataSet()->getRows()[0], $response);
    }
    
    public function getInformacoesSinteticas(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->informacoesSinteticas->getInformacoesSinteticas($request->getDataSet()->getRows()[0], $response);
    }
    
    public function getInformacoesSobreBasesCalculo(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->informacoesSobreBasesCalculo->getInformacoesSobreBasesCalculo($request->getDataSet()->getRows()[0], $response);
    }
}

class ContribuicaoPrevidenciariaSegurado {
    
    public function __construct (HCMParameters $hcmParameters, PreFechamentoDctfWebService $preFechamentoDctfWebService) {
        $this->hcmParameters = $hcmParameters;
        $this->preFechamentoDctfWebService = $preFechamentoDctfWebService;
    }
    
    public function getContribuicaoPrevidenciariaSegurado($row, DTO\Response $response) {
        try {
            $parameters = array( 
                'NRORG'          => $row['NRORG'],
                'NRESTRUTGEREN'  => isset($row['NRESTRUTGEREN']) ? $row['NRESTRUTGEREN'] : '',
                'DTMESCOMPETENC' => $row['DATACOMPETENCIAINICIAL'],
                'NRESTRUTLEGAL'  => isset($row['NRESTRUTLEGAL_LIST']) ? $row['NRESTRUTLEGAL_LIST'] : '',
                'NRTABELA'       => isset($row['APURACAO']) ? $row['APURACAO'] : null
            );

            $contribuicaoPrevidenciaria = $this->preFechamentoDctfWebService->getContribuicaoPrevidenciaria($parameters);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('dataset', $contribuicaoPrevidenciaria));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getEventosApurados($row, DTO\Response $response) {
        try {
            $parameters = array( 
                'NRORG'             => $this->hcmParameters->getNrorgTrabalho(),
                'COMPETENCIA'       => $row['PERIODO'],
                'NRTIPOMOVIMENT'    => $row['NRTABELA'],
                'NRVINCULOM'        => $row['VINCULO'],
                'DIFERENCA_BASE'    => $row['DIFERENCA_BASE'],
                'CONCLUSAO'         => $row['CONCLUSAO'],
                'MODALIDADECALCULO' => 1,
                'OCORRENCIACALCULO' => 1
            );
            
            $eventosApuradosVinculo = $this->preFechamentoDctfWebService->getEventosApuradosContribuicao($parameters);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('dataset', $eventosApuradosVinculo));
        } catch(\Exception $e) {
           $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode())); 
        }
    }
}

class InformacoesSinteticas {
    
    public function __construct (HCMParameters $hcmParameters, PreFechamentoDctfWebService $preFechamentoDctfWebService) {
        $this->hcmParameters = $hcmParameters;
        $this->preFechamentoDctfWebService = $preFechamentoDctfWebService;
    }
    
    public function getInformacoesSinteticas($row, DTO\Response $response) {
        try {
            $parameters = array( 
                'NRORG'          => $row['NRORG'],
                'NRESTRUTGEREN'  => isset($row['NRESTRUTGEREN']) ? $row['NRESTRUTGEREN'] : '',
                'DTMESCOMPETENC' => $row['DATACOMPETENCIAINICIAL'],
                'NRESTRUTLEGAL'  => isset($row['NRESTRUTLEGAL_LIST']) ? $row['NRESTRUTLEGAL_LIST'] : '',
                'NRTABELA'       => isset($row['APURACAO']) ? $row['APURACAO'] : null
            );

            $informacoesSinteticas = $this->preFechamentoDctfWebService->getInformacoesSinteticas($parameters);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('dataset', $informacoesSinteticas));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

class InformacoesSobreBasesCalculo {
    
    public function __construct (HCMParameters $hcmParameters, PreFechamentoDctfWebService $preFechamentoDctfWebService) {
        $this->hcmParameters = $hcmParameters;
        $this->preFechamentoDctfWebService = $preFechamentoDctfWebService;
    }
    
    public function getInformacoesSobreBasesCalculo($row, DTO\Response $response) {
        try {
            $parameters = array( 
                'NRORG'          => $row['NRORG'],
                'NRESTRUTGEREN'  => isset($row['NRESTRUTGEREN']) ? $row['NRESTRUTGEREN'] : '',
                'DTMESCOMPETENC' => $row['DATACOMPETENCIAINICIAL'],
                'NRESTRUTLEGAL'  => isset($row['NRESTRUTLEGAL_LIST']) ? $row['NRESTRUTLEGAL_LIST'] : '',
                'NRTABELA'       => isset($row['APURACAO']) ? $row['APURACAO'] : null
            );

            $informacoesSobreBasesCalculo = $this->preFechamentoDctfWebService->getInformacoesSobreBasesCalculo($parameters);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('dataset', $informacoesSobreBasesCalculo));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}